@@ -19,8 +19,16 @@ class Craigslist:
         options = Options()
         current_directory = Path().absolute()
         options.add_argument(f"user-data-dir={current_directory}/sessions/{username}")
+        options.add_argument('--headless')
         options.add_argument("--window-size=1920,1080")
+        options.add_argument("--nogpu")
+        options.add_argument("--disable-gpu")
+        options.add_argument("user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36")
+        options.add_argument("--no-sandbox")
         options.add_argument("--enable-javascript")
+        options.add_experimental_option("excludeSwitches", ["enable-automation"])
+        options.add_experimental_option('useAutomationExtension', False)
+        options.add_argument('--disable-blink-features=AutomationControlled')
         self.driver = webdriver.Chrome(service=Service(ChromeDriverManager().install()), chrome_options=options)
 
     def get_login_page(self):
